from setuptools import setup

setup(name='distributions_tb',
      version='0.1',
      description='Different distributions',
      packages=['distributions_tb'],
      author='Thomas Breuer',
      zip_safe=False)
